==> gamemaster-0.0.1.tar.gz: gamemaster/client.php <==
<?php
error_reporting(E_ALL);

print "Starting script...\n";
$command = array('command' => 'new',
		'length' => 10,
		'name' => 'A test session!',
		'game' => 'cs:s',
		'executable' => '/bin/echo',
		'working_dir' => '/home/gamemaster',
		'config_filename' => '/home/gamemaster/test.cfg',
		'config_contents' => "sv_password kebab\nsome_stuff elite");

$address = '127.0.0.1';
$port = 4554;

$json_command = json_encode($command) . "\n";

print "Creating socket...\n";
if (($socket = socket_create(AF_INET, SOCK_STREAM,
		getprotobyname('tcp'))) === FALSE) {
	die("Unable to create TCP socket.\n");
}

print "Connecting to remote host $address on port $port...\n";
if (!socket_connect($socket, $address, $port)) {
	die("Unable to connect to remote host.\n");
}

print "Writing command to socket...\n";
if (($bytes_written = socket_write($socket, $json_command)) === FALSE) {
	die("Unable to write JSON encoded data to socket.\n");
}

print "Reading response from socket...\n";
if (($response_json = socket_read($socket, 2048, PHP_NORMAL_READ)) === FALSE) {
	die("Unable to read server response from socket.\n");
}
print "Closing socket...\n";
socket_close($socket);

$response = json_decode($response_json, true);

print "Command status: " . $response['status'] . "\n";

if ($response['response'] == 'list') {

	print "'List' command response received.\n";

	foreach ($response['sessions'] as $pid => $session) {
		print "Session \"" . $session['name'] . "\", PID: " . $pid .
				", Start time: " . $session['start_time'] . ", End time: " .
				$session['end_time'] . "\n";
	}

} elseif ($response['response'] == 'new') {

	print "'New' command response received.\n";

} elseif ($response['response'] == 'terminate') {

	print "'Terminate' command response received.\n";

} elseif ($response['response'] == 'modify') {

	print "'Modify' command response received.\n";

} elseif ($response['response'] == 'error') {
	print "'Error' response was returned.\n";
}

?>

==> gamemaster-0.0.2.tar.gz: gamemaster/client.php <==
<?php
error_reporting(E_ALL);

print "Starting script...\n";
$command = array('command' => 'new',
		'length' => 60,
		'name' => 'A test session!',
		'game' => 'cs:s',
		'executable' => '/home/gamemaster/gamemaster/child_process.pl',
		'working_dir' => '/home/gamemaster/gamemaster',
		'config_filename' => '/home/gamemaster/gamemaster/test.cfg',
		'config_contents' => "sv_password kebab\nsome_stuff elite");

$address = '127.0.0.1';
$port = 4554;

$json_command = json_encode($command) . "\n";

print "Creating socket...\n";
if (($socket = socket_create(AF_INET, SOCK_STREAM,
		getprotobyname('tcp'))) === FALSE) {
	die("Unable to create TCP socket.\n");
}

print "Connecting to remote host $address on port $port...\n";
if (!socket_connect($socket, $address, $port)) {
	die("Unable to connect to remote host.\n");
}

print "Writing command to socket...\n";
if (($bytes_written = socket_write($socket, $json_command)) === FALSE) {
	die("Unable to write JSON encoded data to socket.\n");
}

print "Reading response from socket...\n";
if (($response_json = socket_read($socket, 2048, PHP_NORMAL_READ)) === FALSE) {
	die("Unable to read server response from socket.\n");
}
print "Closing socket...\n";
socket_close($socket);

$response = json_decode($response_json, true);

print "Command status: " . $response['status'] . "\n";

if ($response['response'] == 'list') {

	print "'List' command response received.\n";

	foreach ($response['sessions'] as $pid => $session) {
		print "Session \"" . $session['name'] . "\", PID: " . $pid .
				", Start time: " . $session['start_time'] . ", End time: " .
				$session['end_time'] . "\n";
	}

} elseif ($response['response'] == 'new') {

	print "'New' command response received.\n";

} elseif ($response['response'] == 'terminate') {

	print "'Terminate' command response received.\n";

} elseif ($response['response'] == 'modify') {

	print "'Modify' command response received.\n";

} elseif ($response['response'] == 'error') {
	print "'Error' response was returned.\n";
}

?>
